-- Using this script: Do a find and replace on the following tables to update them to match the year of data you're working with. (It's alright to let find and replace update this comment too.)
-- Emp_2016
--
-- Script outputs to the following tables: Emp_2016_Condensed, Emp_2016_Unmatched.
-- This script combines multiple company locations in the Emp table down to one location. It is very likely the Emp_2016_Unmatched table will be empty after this process, and it is safe to delete it if it is.
-- Expected run time: 2-3 minutes.

BEGIN TRANSACTION
	SET NOCOUNT ON;

	IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE Table_Name='Emp_2016_Condensed')
	BEGIN
		DROP TABLE Emp_2016_Condensed;
	END

	IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE Table_Name='Emp_2016_Unmatched')
	BEGIN
		DROP TABLE Emp_2016_Unmatched;
	END
	
    SELECT * INTO #Emp_2016_Working
	FROM Emp_2016;
	
	SELECT distinct ui_acct, SUM(ISNULL(CAST(M1_EMPL AS INT),0)) as M1_EMPL, SUM(ISNULL(CAST(M2_EMPL AS INT),0)) as M2_EMPL, SUM(ISNULL(CAST(M3_EMPL AS INT),0)) as M3_EMPL, SUM(ISNULL(CAST(M4_EMPL AS INT),0)) as M4_EMPL, SUM(ISNULL(CAST(M5_EMPL AS INT),0)) as M5_EMPL, SUM(ISNULL(CAST(M6_EMPL AS INT),0)) as M6_EMPL, SUM(ISNULL(CAST(M7_EMPL AS INT),0)) as M7_EMPL, SUM(ISNULL(CAST(M8_EMPL AS INT),0)) as M8_EMPL, SUM(ISNULL(CAST(M9_EMPL AS INT),0)) as M9_EMPL, SUM(ISNULL(CAST(M10_EMPL AS INT),0)) as M10_EMPL, SUM(ISNULL(CAST(M11_EMPL AS INT),0)) as M11_EMPL, SUM(ISNULL(CAST(M12_EMPL AS INT),0)) as M12_EMPL, SUM(ISNULL(CAST(M1_EMPL AS INT),0) + ISNULL(M2_EMPL,0) + ISNULL(M3_EMPL,0) + ISNULL(M4_EMPL,0) + ISNULL(M5_EMPL,0) + ISNULL(M6_EMPL,0) + ISNULL(M7_EMPL,0) + ISNULL(M8_EMPL,0) + ISNULL(M9_EMPL,0) + ISNULL(M10_EMPL,0) + ISNULL(M11_EMPL,0) + ISNULL(M12_EMPL,0)) as employees
	INTO #EmployeeCount
	FROM Emp_2016
	GROUP BY ui_acct;

	--Step 1, match on all 6 digits of NAICS code
	SELECT distinct ui_acct, naics, SUM(ISNULL(CAST(M1_EMPL AS INT),0) + ISNULL(M2_EMPL,0) + ISNULL(M3_EMPL,0) + ISNULL(M4_EMPL,0) + ISNULL(M5_EMPL,0) + ISNULL(M6_EMPL,0) + ISNULL(M7_EMPL,0) + ISNULL(M8_EMPL,0) + ISNULL(M9_EMPL,0) + ISNULL(M10_EMPL,0) + ISNULL(M11_EMPL,0) + ISNULL(M12_EMPL,0)) as employees
	INTO #EmployeeNaicsCount
	FROM Emp_2016
	GROUP BY ui_acct, naics;

	SELECT enc.naics, qcew.Year, qcew.QTR, qcew.UI_ACCT, qcew.RPT_UNIT, qcew.EIN, qcew.LEGAL_NAME, qcew.TRADE_NAME, qcew.UI_ADDRESS, qcew.UI_ADDRESS_2, qcew.UI_CITY, qcew.UI_STATE, qcew.UI_ZIP_5, qcew.MLOT_ADDRESS, qcew.MLOT_ADDRESS2, qcew.MLOT_CITY, qcew.MLOT_STATE, qcew.MLOT_ZIP_5, qcew.ADDR_TYPE, qcew.CNTY, qcew.OWN_1, ec.M1_EMPL, ec.M2_EMPL, ec.M3_EMPL, ec.M4_EMPL, ec.M5_EMPL, ec.M6_EMPL, ec.M7_EMPL, ec.M8_EMPL, ec.M9_EMPL, ec.M10_EMPL, ec.M11_EMPL, ec.M12_EMPL, qcew.TOTAL_WAGE, qcew.NUMBER_OF_YEARS_IN_BUSINESS, qcew.SETUP_MON, qcew.SETUP_DAY, qcew.SETUP_YEAR, qcew.LIAB_MON, qcew.LIAB_DAY, qcew.LIAB_YEAR, qcew.EOL_MON, qcew.EOL_DAY, qcew.EOL_YEAR, qcew.REACT_MON, qcew.REACT_DAY, qcew.REACT_YEAR, qcew.RPT_UNIT_DESC, qcew.MEEI, qcew.QCEW_Seq, 1 as CompressionRule
	INTO Emp_2016_Condensed
	FROM #Emp_2016_Working qcew
	INNER JOIN #EmployeeCount ec ON ec.ui_acct = qcew.ui_acct
	INNER JOIN #EmployeeNaicsCount enc ON enc.ui_acct = ec.ui_acct
	WHERE (4 * enc.employees) >= (3 * ec.employees) -- At least 75% of employees have same NAICS code
	AND qcew.rpt_unit = 0; 

	DELETE FROM #Emp_2016_Working
	WHERE QCEW_Seq IN (SELECT QCEW_Seq FROM Emp_2016_Condensed);

	--Step 2, match on left 4 digits of NAICS code
	SELECT distinct ui_acct, LEFT(naics, 4) as NAICS, SUM(ISNULL(CAST(M1_EMPL AS INT),0)) as M1_EMPL, SUM(ISNULL(CAST(M2_EMPL AS INT),0)) as M2_EMPL, SUM(ISNULL(CAST(M3_EMPL AS INT),0)) as M3_EMPL, SUM(ISNULL(CAST(M4_EMPL AS INT),0)) as M4_EMPL, SUM(ISNULL(CAST(M5_EMPL AS INT),0)) as M5_EMPL, SUM(ISNULL(CAST(M6_EMPL AS INT),0)) as M6_EMPL, SUM(ISNULL(CAST(M7_EMPL AS INT),0)) as M7_EMPL, SUM(ISNULL(CAST(M8_EMPL AS INT),0)) as M8_EMPL, SUM(ISNULL(CAST(M9_EMPL AS INT),0)) as M9_EMPL, SUM(ISNULL(CAST(M10_EMPL AS INT),0)) as M10_EMPL, SUM(ISNULL(CAST(M11_EMPL AS INT),0)) as M11_EMPL, SUM(ISNULL(CAST(M12_EMPL AS INT),0)) as M12_EMPL, SUM(ISNULL(CAST(M1_EMPL AS INT),0) + ISNULL(M2_EMPL,0) + ISNULL(M3_EMPL,0) + ISNULL(M4_EMPL,0) + ISNULL(M5_EMPL,0) + ISNULL(M6_EMPL,0) + ISNULL(M7_EMPL,0) + ISNULL(M8_EMPL,0) + ISNULL(M9_EMPL,0) + ISNULL(M10_EMPL,0) + ISNULL(M11_EMPL,0) + ISNULL(M12_EMPL,0)) as employees
	INTO #EmployeeNaics4Count
	FROM #Emp_2016_Working
	GROUP BY ui_acct, LEFT(naics, 4);

	INSERT INTO Emp_2016_Condensed
	SELECT enc.naics, qcew.Year, qcew.QTR, qcew.UI_ACCT, qcew.RPT_UNIT, qcew.EIN, qcew.LEGAL_NAME, qcew.TRADE_NAME, qcew.UI_ADDRESS, qcew.UI_ADDRESS_2, qcew.UI_CITY, qcew.UI_STATE, qcew.UI_ZIP_5, qcew.MLOT_ADDRESS, qcew.MLOT_ADDRESS2, qcew.MLOT_CITY, qcew.MLOT_STATE, qcew.MLOT_ZIP_5, qcew.ADDR_TYPE, qcew.CNTY, qcew.OWN_1, ec.M1_EMPL, ec.M2_EMPL, ec.M3_EMPL, ec.M4_EMPL, ec.M5_EMPL, ec.M6_EMPL, ec.M7_EMPL, ec.M8_EMPL, ec.M9_EMPL, ec.M10_EMPL, ec.M11_EMPL, ec.M12_EMPL, qcew.TOTAL_WAGE, qcew.NUMBER_OF_YEARS_IN_BUSINESS, qcew.SETUP_MON, qcew.SETUP_DAY, qcew.SETUP_YEAR, qcew.LIAB_MON, qcew.LIAB_DAY, qcew.LIAB_YEAR, qcew.EOL_MON, qcew.EOL_DAY, qcew.EOL_YEAR, qcew.REACT_MON, qcew.REACT_DAY, qcew.REACT_YEAR, qcew.RPT_UNIT_DESC, qcew.MEEI, qcew.QCEW_Seq, 2 as CompressionRule
	FROM #Emp_2016_Working qcew
	INNER JOIN #EmployeeCount ec ON ec.ui_acct = qcew.ui_acct
	INNER JOIN #EmployeeNaics4Count enc ON enc.ui_acct = ec.ui_acct
	WHERE (4 * enc.employees) >= (3 * ec.employees) -- At least 75% of employees have same NAICS code
	AND qcew.rpt_unit = 0; 

	DELETE FROM #Emp_2016_Working
	WHERE QCEW_Seq IN (SELECT QCEW_Seq FROM Emp_2016_Condensed);

	--Step 2, match on left 3 digits of NAICS code
	SELECT distinct ui_acct, LEFT(naics, 3) as NAICS, SUM(ISNULL(CAST(M1_EMPL AS INT),0)) as M1_EMPL, SUM(ISNULL(CAST(M2_EMPL AS INT),0)) as M2_EMPL, SUM(ISNULL(CAST(M3_EMPL AS INT),0)) as M3_EMPL, SUM(ISNULL(CAST(M4_EMPL AS INT),0)) as M4_EMPL, SUM(ISNULL(CAST(M5_EMPL AS INT),0)) as M5_EMPL, SUM(ISNULL(CAST(M6_EMPL AS INT),0)) as M6_EMPL, SUM(ISNULL(CAST(M7_EMPL AS INT),0)) as M7_EMPL, SUM(ISNULL(CAST(M8_EMPL AS INT),0)) as M8_EMPL, SUM(ISNULL(CAST(M9_EMPL AS INT),0)) as M9_EMPL, SUM(ISNULL(CAST(M10_EMPL AS INT),0)) as M10_EMPL, SUM(ISNULL(CAST(M11_EMPL AS INT),0)) as M11_EMPL, SUM(ISNULL(CAST(M12_EMPL AS INT),0)) as M12_EMPL, SUM(ISNULL(CAST(M1_EMPL AS INT),0) + ISNULL(M2_EMPL,0) + ISNULL(M3_EMPL,0) + ISNULL(M4_EMPL,0) + ISNULL(M5_EMPL,0) + ISNULL(M6_EMPL,0) + ISNULL(M7_EMPL,0) + ISNULL(M8_EMPL,0) + ISNULL(M9_EMPL,0) + ISNULL(M10_EMPL,0) + ISNULL(M11_EMPL,0) + ISNULL(M12_EMPL,0)) as employees
	INTO #EmployeeNaics3Count
	FROM #Emp_2016_Working
	GROUP BY ui_acct, LEFT(naics, 3);
	
	INSERT INTO Emp_2016_Condensed
	SELECT enc.naics, qcew.Year, qcew.QTR, qcew.UI_ACCT, qcew.RPT_UNIT, qcew.EIN, qcew.LEGAL_NAME, qcew.TRADE_NAME, qcew.UI_ADDRESS, qcew.UI_ADDRESS_2, qcew.UI_CITY, qcew.UI_STATE, qcew.UI_ZIP_5, qcew.MLOT_ADDRESS, qcew.MLOT_ADDRESS2, qcew.MLOT_CITY, qcew.MLOT_STATE, qcew.MLOT_ZIP_5, qcew.ADDR_TYPE, qcew.CNTY, qcew.OWN_1, ec.M1_EMPL, ec.M2_EMPL, ec.M3_EMPL, ec.M4_EMPL, ec.M5_EMPL, ec.M6_EMPL, ec.M7_EMPL, ec.M8_EMPL, ec.M9_EMPL, ec.M10_EMPL, ec.M11_EMPL, ec.M12_EMPL, qcew.TOTAL_WAGE, qcew.NUMBER_OF_YEARS_IN_BUSINESS, qcew.SETUP_MON, qcew.SETUP_DAY, qcew.SETUP_YEAR, qcew.LIAB_MON, qcew.LIAB_DAY, qcew.LIAB_YEAR, qcew.EOL_MON, qcew.EOL_DAY, qcew.EOL_YEAR, qcew.REACT_MON, qcew.REACT_DAY, qcew.REACT_YEAR, qcew.RPT_UNIT_DESC, qcew.MEEI, qcew.QCEW_Seq, 3 as CompressionRule
	FROM #Emp_2016_Working qcew
	INNER JOIN #EmployeeCount ec ON ec.ui_acct = qcew.ui_acct
	INNER JOIN #EmployeeNaics4Count enc ON enc.ui_acct = ec.ui_acct
	WHERE (4 * enc.employees) >= (3 * ec.employees) -- At least 75% of employees have same NAICS code
	AND qcew.rpt_unit = 0; 

	DELETE FROM #Emp_2016_Working
	WHERE QCEW_Seq IN (SELECT QCEW_Seq FROM Emp_2016_Condensed);

	--Step 4, match on left 2 digits of NAICS code
	SELECT distinct ui_acct, LEFT(naics, 2) as NAICS, SUM(ISNULL(CAST(M1_EMPL AS INT),0)) as M1_EMPL, SUM(ISNULL(CAST(M2_EMPL AS INT),0)) as M2_EMPL, SUM(ISNULL(CAST(M3_EMPL AS INT),0)) as M3_EMPL, SUM(ISNULL(CAST(M4_EMPL AS INT),0)) as M4_EMPL, SUM(ISNULL(CAST(M5_EMPL AS INT),0)) as M5_EMPL, SUM(ISNULL(CAST(M6_EMPL AS INT),0)) as M6_EMPL, SUM(ISNULL(CAST(M7_EMPL AS INT),0)) as M7_EMPL, SUM(ISNULL(CAST(M8_EMPL AS INT),0)) as M8_EMPL, SUM(ISNULL(CAST(M9_EMPL AS INT),0)) as M9_EMPL, SUM(ISNULL(CAST(M10_EMPL AS INT),0)) as M10_EMPL, SUM(ISNULL(CAST(M11_EMPL AS INT),0)) as M11_EMPL, SUM(ISNULL(CAST(M12_EMPL AS INT),0)) as M12_EMPL, SUM(ISNULL(CAST(M1_EMPL AS INT),0) + ISNULL(M2_EMPL,0) + ISNULL(M3_EMPL,0) + ISNULL(M4_EMPL,0) + ISNULL(M5_EMPL,0) + ISNULL(M6_EMPL,0) + ISNULL(M7_EMPL,0) + ISNULL(M8_EMPL,0) + ISNULL(M9_EMPL,0) + ISNULL(M10_EMPL,0) + ISNULL(M11_EMPL,0) + ISNULL(M12_EMPL,0)) as employees
	INTO #EmployeeNaics2Count
	FROM #Emp_2016_Working
	GROUP BY ui_acct, LEFT(naics, 2);
	
	INSERT INTO Emp_2016_Condensed
	SELECT enc.naics, qcew.Year, qcew.QTR, qcew.UI_ACCT, qcew.RPT_UNIT, qcew.EIN, qcew.LEGAL_NAME, qcew.TRADE_NAME, qcew.UI_ADDRESS, qcew.UI_ADDRESS_2, qcew.UI_CITY, qcew.UI_STATE, qcew.UI_ZIP_5, qcew.MLOT_ADDRESS, qcew.MLOT_ADDRESS2, qcew.MLOT_CITY, qcew.MLOT_STATE, qcew.MLOT_ZIP_5, qcew.ADDR_TYPE, qcew.CNTY, qcew.OWN_1, ec.M1_EMPL, ec.M2_EMPL, ec.M3_EMPL, ec.M4_EMPL, ec.M5_EMPL, ec.M6_EMPL, ec.M7_EMPL, ec.M8_EMPL, ec.M9_EMPL, ec.M10_EMPL, ec.M11_EMPL, ec.M12_EMPL, qcew.TOTAL_WAGE, qcew.NUMBER_OF_YEARS_IN_BUSINESS, qcew.SETUP_MON, qcew.SETUP_DAY, qcew.SETUP_YEAR, qcew.LIAB_MON, qcew.LIAB_DAY, qcew.LIAB_YEAR, qcew.EOL_MON, qcew.EOL_DAY, qcew.EOL_YEAR, qcew.REACT_MON, qcew.REACT_DAY, qcew.REACT_YEAR, qcew.RPT_UNIT_DESC, qcew.MEEI, qcew.QCEW_Seq, 4 as CompressionRule
	FROM #Emp_2016_Working qcew
	INNER JOIN #EmployeeCount ec ON ec.ui_acct = qcew.ui_acct
	INNER JOIN #EmployeeNaics2Count enc ON enc.ui_acct = ec.ui_acct
	WHERE (4 * enc.employees) >= (3 * ec.employees) -- At least 75% of employees have same NAICS code
	AND qcew.rpt_unit = 0; 

	DELETE FROM #Emp_2016_Working
	WHERE QCEW_Seq IN (SELECT QCEW_Seq FROM Emp_2016_Condensed);

	--Step 5, match on NAICS code with most employees
	INSERT INTO Emp_2016_Condensed
	SELECT maxEmp.naics, qcew.Year, qcew.QTR, qcew.UI_ACCT, qcew.RPT_UNIT, qcew.EIN, qcew.LEGAL_NAME, qcew.TRADE_NAME, qcew.UI_ADDRESS, qcew.UI_ADDRESS_2, qcew.UI_CITY, qcew.UI_STATE, qcew.UI_ZIP_5, qcew.MLOT_ADDRESS, qcew.MLOT_ADDRESS2, qcew.MLOT_CITY, qcew.MLOT_STATE, qcew.MLOT_ZIP_5, qcew.ADDR_TYPE, qcew.CNTY, qcew.OWN_1, maxEmp.M1_EMPL, maxEmp.M2_EMPL, maxEmp.M3_EMPL, maxEmp.M4_EMPL, maxEmp.M5_EMPL, maxEmp.M6_EMPL, maxEmp.M7_EMPL, maxEmp.M8_EMPL, maxEmp.M9_EMPL, maxEmp.M10_EMPL, maxEmp.M11_EMPL, maxEmp.M12_EMPL, qcew.TOTAL_WAGE, qcew.NUMBER_OF_YEARS_IN_BUSINESS, qcew.SETUP_MON, qcew.SETUP_DAY, qcew.SETUP_YEAR, qcew.LIAB_MON, qcew.LIAB_DAY, qcew.LIAB_YEAR, qcew.EOL_MON, qcew.EOL_DAY, qcew.EOL_YEAR, qcew.REACT_MON, qcew.REACT_DAY, qcew.REACT_YEAR, qcew.RPT_UNIT_DESC, qcew.MEEI, qcew.QCEW_Seq, 5 as CompressionRule
	FROM #Emp_2016_Working qcew
	INNER JOIN (
		SELECT combinedEmps.ui_acct, naics, M1_EMPL, M2_EMPL, M3_EMPL, M4_EMPL, M5_EMPL, M6_EMPL, M7_EMPL, M8_EMPL, M9_EMPL, M10_EMPL, M11_EMPL, M12_EMPL FROM (
			SELECT ui_acct, SUM(M1_EMPL) as M1_EMPL, SUM(M2_EMPL) as M2_EMPL, SUM(M3_EMPL) as M3_EMPL, SUM(M4_EMPL) as M4_EMPL, SUM(M5_EMPL) as M5_EMPL, SUM(M6_EMPL) as M6_EMPL, SUM(M7_EMPL) as M7_EMPL, SUM(M8_EMPL) as M8_EMPL, SUM(M9_EMPL) as M9_EMPL, SUM(M10_EMPL) as M10_EMPL, SUM(M11_EMPL) as M11_EMPL, SUM(M12_EMPL) as M12_EMPL
			FROM #EmployeeCount ec
			group by ui_acct
		) combinedEmps
		INNER JOIN (
			SELECT ui_acct, naics
			FROM #EmployeeNaicsCount enc
			where employees = (SELECT MAX(employees) FROM #EmployeeNaicsCount where ui_acct = enc.ui_acct)
		) naics ON naics.ui_acct = combinedEmps.ui_acct
	) maxEmp ON maxEmp.ui_acct = qcew.ui_acct
	where rpt_unit = 0;

	DELETE FROM #Emp_2016_Working
	WHERE QCEW_Seq IN (SELECT QCEW_Seq FROM Emp_2016_Condensed);

	--cleanup
	SELECT * INTO Emp_2016_Unmatched
	FROM #Emp_2016_Working
	where rpt_unit = 0;

	DROP TABLE #Emp_2016_Working;
	DROP TABLE #EmployeeNaicsCount;
	DROP TABLE #EmployeeNaics4Count;
	DROP TABLE #EmployeeNaics3Count;
	DROP TABLE #EmployeeNaics2Count;
	DROP TABLE #EmployeeCount;

COMMIT