BEGIN TRANSACTION

-- Using this script: Do a find and replace on the following table names to update them to the current year. (It's alright to let find and replace update this comment too.)
-- Match_2016
-- Match_2016_Unmatched
-- Match_2016_FEINOnly
-- Emp_2016_Condensed
-- WC_2016
--
-- Script outputs to the following tables: Match_2016, Match_2016_Unmatched, Match_2016_FEINOnly. With the current algorithm, the unmatched table should be empty.
-- Note: The Soundex matching portion of this script takes awhile to run. Expect run times of around 2-4 hours.

IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE Table_Name='Match_2016')
BEGIN
	DROP TABLE Match_2016;
END

IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE Table_Name='Match_2016_Unmatched')
BEGIN
	DROP TABLE Match_2016_Unmatched;
END

IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE Table_Name='Match_2016_FEINOnly')
BEGIN
	DROP TABLE Match_2016_FEINOnly;
END

DECLARE @MaxDistance INT
SET @MaxDistance = 5

select * into #Working_WC from wc_2016;

--We start this off by trying to figure out if we already have a match for this company
select distinct qcew.*, wc.*,
0 as distance
into #Match_PreviousMatch from Emp_2016_condensed qcew
inner join UI_Acct_Employer oldMatches ON oldMatches.ui_acct = qcew.ui_acct
inner join #Working_WC wc ON oldMatches.[Employer Name] = wc.[Employer Name] AND oldMatches.[Employer Street Address] = wc.[Employer Street Address] AND oldMatches.[Employer City] = wc.[Employer City] AND oldMatches.[Last 4 FEIN] = wc.[Last 4 FEIN];

DELETE FROM #Working_WC
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_PreviousMatch
)

SELECT *, 'Old Match          ' as matching_algorithm, 1 as confirmedMatch
into Match_2016
from #Match_PreviousMatch

ALTER TABLE Match_2016 ALTER COLUMN distance int null;

DROP TABLE #Match_PreviousMatch

--Step 1, match on all possible criteria
select distinct *, 
dbo.MinOf(dbo.Levenshtein(wc.[Employer Name], qcew.legal_name, @MaxDistance), dbo.Levenshtein(wc.[Employer Name], qcew.trade_name, @MaxDistance)) +
dbo.MinOf(dbo.Levenshtein(wc.[Employer Street Address], qcew.ui_address, @MaxDistance), dbo.Levenshtein(wc.[Employer Street Address], qcew.mlot_address, @MaxDistance)) +
dbo.MinOf(dbo.Levenshtein(wc.[Employer City], qcew.ui_city, @MaxDistance), dbo.Levenshtein(wc.[Employer City], qcew.mlot_city, @MaxDistance))
as distance 
into #Match_All6 from Emp_2016_condensed qcew
inner join #Working_WC wc 
on  ((wc.[Employer Name] = qcew.legal_name OR wc.[Employer Name] = qcew.trade_name) OR ((dbo.Levenshtein(wc.[Employer Name], qcew.legal_name, @MaxDistance) IS NOT NULL OR dbo.Levenshtein(wc.[Employer Name], qcew.trade_name, @MaxDistance) IS NOT NULL) AND LEN(wc.[Employer Name]) > @MaxDistance))
AND (wc.[Last 4 FEIN] = RIGHT(qcew.EIN, 4))
AND (
		(wc.[Employer Street Address] = qcew.ui_address OR wc.[Employer Street Address] = qcew.ui_address) OR 
		(dbo.Levenshtein(wc.[Employer Street Address], qcew.ui_address, @MaxDistance) IS NOT NULL OR dbo.Levenshtein(wc.[Employer Street Address], qcew.mlot_address, @MaxDistance) IS NOT NULL)
	)
AND (dbo.Levenshtein(wc.[Employer City], qcew.ui_city, @MaxDistance) IS NOT NULL OR dbo.Levenshtein(wc.[Employer City], qcew.mlot_city, @MaxDistance) IS NOT NULL)
AND (wc.[Employer State] = qcew.ui_state OR wc.[Employer State] = qcew.mlot_state)
AND (CAST(wc.[Employer Zip] AS nvarchar) = qcew.ui_zip_5 OR CAST(wc.[Employer Zip] AS nvarchar) = qcew.mlot_zip_5)

DELETE FROM #Working_WC
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_All6
)

--step 2, only last 4 FEIN and address
select distinct *,
dbo.MinOf(dbo.Levenshtein(wc.[Employer Street Address], qcew.ui_address, @MaxDistance), dbo.Levenshtein(wc.[Employer Street Address], qcew.mlot_address, @MaxDistance))
as distance
into #Match_AddrAndFEIN from Emp_2016_condensed qcew
inner join #Working_WC wc 
on (wc.[Last 4 FEIN] = RIGHT(qcew.EIN, 4))
AND (
		(wc.[Employer Street Address] = qcew.ui_address OR wc.[Employer Street Address] = qcew.ui_address) OR 
		(dbo.Levenshtein(wc.[Employer Street Address], qcew.ui_address, @MaxDistance) IS NOT NULL OR dbo.Levenshtein(wc.[Employer Street Address], qcew.mlot_address, @MaxDistance) IS NOT NULL)
	)
AND (dbo.Levenshtein(wc.[Employer City], qcew.ui_city, @MaxDistance) IS NOT NULL OR dbo.Levenshtein(wc.[Employer City], qcew.mlot_city, @MaxDistance) IS NOT NULL)
AND (wc.[Employer State] = qcew.ui_state OR wc.[Employer State] = qcew.mlot_state)
AND (CAST(wc.[Employer Zip] AS nvarchar) = qcew.ui_zip_5 OR CAST(wc.[Employer Zip] AS nvarchar) = qcew.mlot_zip_5)

DELETE FROM #Working_WC 
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_AddrAndFEIN
)

--step 3, only employer name and last 4 FEIN
select distinct *, 
dbo.MinOf(dbo.Levenshtein(wc.[Employer Name], qcew.legal_name, @MaxDistance), dbo.Levenshtein(wc.[Employer Name], qcew.trade_name, @MaxDistance))
as distance
into #Match_NameAndFEIN from Emp_2016_condensed qcew
inner join #Working_WC wc 
on  ((wc.[Employer Name] = qcew.legal_name OR wc.[Employer Name] = qcew.trade_name) OR ((dbo.Levenshtein(wc.[Employer Name], qcew.legal_name, @MaxDistance) IS NOT NULL OR dbo.Levenshtein(wc.[Employer Name], qcew.trade_name, @MaxDistance) IS NOT NULL) AND LEN(wc.[Employer Name]) > @MaxDistance))
AND (wc.[Last 4 FEIN] = RIGHT(qcew.EIN, 4))

DELETE FROM #Working_WC 
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_NameAndFEIN
)

INSERT into Match_2016
SELECT *, 'Levenshtein5 - 1' as matching_algorithm, 0 as confirmedMatch
from #Match_All6

INSERT into Match_2016
SELECT *, 'Levenshtein5 - 2' as matching_algorithm, 0 as confirmedMatch
from #Match_AddrAndFEIN

INSERT into Match_2016
SELECT *, 'Levenshtein5 - 3' as matching_algorithm, 0 as confirmedMatch
from #Match_NameAndFEIN

drop table #Match_AddrAndFEIN;
drop table #Match_All6;
drop table #Match_NameAndFEIN;

--PART 2, RETURN OF THE SOUNDEX
--step 1, all of the criteria

select distinct * into #Match_All62 from Emp_2016_condensed qcew
inner join #Working_WC wc 
on (Difference(wc.[Employer Name], qcew.legal_name) >= 4 OR Difference(wc.[Employer Name], qcew.trade_name) >= 4) 
AND (wc.[Last 4 FEIN] = RIGHT(qcew.EIN, 4))
AND (
		(wc.[Employer Street Address] = qcew.ui_address OR wc.[Employer Street Address] = qcew.ui_address) OR 
		((Difference(wc.[Employer Street Address], qcew.ui_address) >= 4 OR  Difference(wc.[Employer Street Address], qcew.mlot_address) >= 4) AND wc.[Employer Street Address] NOT LIKE '%PO BOX%')
	)
AND (Difference(wc.[Employer Street Address], qcew.ui_address) >= 4 OR Difference(wc.[Employer Street Address], qcew.mlot_address) >= 4)
AND (Difference(wc.[Employer City], qcew.ui_city) >= 4 OR Difference(wc.[Employer City], qcew.mlot_city) >= 4)
AND (wc.[Employer State] = qcew.ui_state OR wc.[Employer State] = qcew.mlot_state)
AND (CAST(wc.[Employer Zip] AS nvarchar) = qcew.ui_zip_5 OR CAST(wc.[Employer Zip] AS nvarchar) = qcew.mlot_zip_5)

DELETE FROM #Working_WC 
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_All62
)

--step 2, only employer name and last 4 FEIN
select distinct * into #Match_NameAndFEIN2 from Emp_2016_condensed qcew
inner join #Working_WC wc 
on (Difference(wc.[Employer Name], qcew.legal_name) >= 4 OR Difference(wc.[Employer Name], qcew.trade_name) >= 4) 
AND (wc.[Last 4 FEIN] = RIGHT(qcew.EIN, 4))

DELETE FROM #Working_WC 
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_NameAndFEIN2
)

--step 3, only last 4 FEIN and address
select distinct * into #Match_AddrAndFEIN2 from Emp_2016_condensed qcew
inner join #Working_WC wc 
on (wc.[Last 4 FEIN] = RIGHT(qcew.EIN, 4))
AND (
		(wc.[Employer Street Address] = qcew.ui_address OR wc.[Employer Street Address] = qcew.ui_address) OR 
		((Difference(wc.[Employer Street Address], qcew.ui_address) >= 4 OR  Difference(wc.[Employer Street Address], qcew.mlot_address) >= 4) AND wc.[Employer Street Address] NOT LIKE '%PO BOX%')
	)
AND (Difference(wc.[Employer City], qcew.ui_city) >= 4 OR Difference(wc.[Employer City], qcew.mlot_city) >= 4)
AND (wc.[Employer State] = qcew.ui_state OR wc.[Employer State] = qcew.mlot_state)
AND (CAST(wc.[Employer Zip] AS nvarchar) = qcew.ui_zip_5 OR CAST(wc.[Employer Zip] AS nvarchar) = qcew.mlot_zip_5)

DELETE FROM #Working_WC 
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_AddrAndFEIN2
)

raiserror('easy soundex compares complete', 10, 1) WITH NOWAIT

--step 4, fuzzy company name and exact address
select distinct * into #Match_2016_exactAddrAndName2 from Emp_2016_condensed qcew
inner join #Working_WC wc 
on (Difference(wc.[Employer Name], qcew.legal_name) >= 4 OR Difference(wc.[Employer Name], qcew.trade_name) >= 4) 
AND (wc.[Employer Street Address] = qcew.ui_address OR wc.[Employer Street Address] = qcew.mlot_address)
AND (wc.[Employer City] = qcew.ui_city OR wc.[Employer City] = qcew.mlot_city)
AND (wc.[Employer State] = qcew.ui_state OR wc.[Employer State] = qcew.mlot_state)
AND (CAST(wc.[Employer Zip] AS nvarchar) = qcew.ui_zip_5 OR CAST(wc.[Employer Zip] AS nvarchar) = qcew.mlot_zip_5)

DELETE FROM #Working_WC 
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_2016_exactAddrAndName2
)


raiserror('hard soundex compare 1 complete', 10, 1) WITH NOWAIT

--step 5, only exact company name and fuzzy address
select distinct * into #Match_2016_AddrAndExactName2 from Emp_2016_condensed qcew
inner join #Working_WC wc 
on (wc.[Employer Name] = qcew.legal_name OR wc.[Employer Name] = qcew.trade_name) 
AND (
		(wc.[Employer Street Address] = qcew.ui_address OR wc.[Employer Street Address] = qcew.ui_address) OR 
		((Difference(wc.[Employer Street Address], qcew.ui_address) >= 4 OR  Difference(wc.[Employer Street Address], qcew.mlot_address) >= 4) AND wc.[Employer Street Address] NOT LIKE '%PO BOX%')
	)
AND (Difference(wc.[Employer City], qcew.ui_city) >= 4 OR Difference(wc.[Employer City], qcew.mlot_city) >= 4)
AND (wc.[Employer State] = qcew.ui_state OR wc.[Employer State] = qcew.mlot_state)
AND (CAST(wc.[Employer Zip] AS nvarchar) = qcew.ui_zip_5 OR CAST(wc.[Employer Zip] AS nvarchar) = qcew.mlot_zip_5)

DELETE FROM #Working_WC 
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_2016_AddrAndExactName2
)

raiserror('hard soundex compare 2 complete', 10, 1) WITH NOWAIT

--step 6, only fuzzy company name and fuzzy address
select distinct * into #Match_2016_AddrAndName2 from Emp_2016_condensed qcew
inner join #Working_WC wc 
on (Difference(wc.[Employer Name], qcew.legal_name) >= 4 OR Difference(wc.[Employer Name], qcew.trade_name) >= 4) 
AND (
		(wc.[Employer Street Address] = qcew.ui_address OR wc.[Employer Street Address] = qcew.ui_address) OR 
		((Difference(wc.[Employer Street Address], qcew.ui_address) >= 4 OR  Difference(wc.[Employer Street Address], qcew.mlot_address) >= 4) AND wc.[Employer Street Address] NOT LIKE '%PO BOX%')
	)
AND (Difference(wc.[Employer City], qcew.ui_city) >= 4 OR Difference(wc.[Employer City], qcew.mlot_city) >= 4)
AND (wc.[Employer State] = qcew.ui_state OR wc.[Employer State] = qcew.mlot_state)
AND (CAST(wc.[Employer Zip] AS nvarchar) = qcew.ui_zip_5 OR CAST(wc.[Employer Zip] AS nvarchar) = qcew.mlot_zip_5)

DELETE FROM #Working_WC 
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_2016_AddrAndName2
)

raiserror('hard soundex compare 3 complete', 10, 1) WITH NOWAIT

--part 3? Match remaining on just FEIN.
select distinct * into #Match_2016_FEINOnly2 from Emp_2016_condensed qcew
inner join #Working_WC wc
on (wc.[Last 4 FEIN] = RIGHT(qcew.EIN, 4))

DELETE FROM #Working_WC
WHERE wc_seq IN (
	SELECT wc_seq FROM #Match_2016_FEINOnly2
)

INSERT INTO Match_2016
SELECT *, null as distance, 'Soundex - 1' as matching_algorithm, 0 as confirmedMatch
from #Match_All62

INSERT into Match_2016
SELECT *, null as distance, 'Soundex - 2' as matching_algorithm, 0 as confirmedMatch
from #Match_NameAndFEIN2

INSERT into Match_2016
SELECT *, null as distance, 'Soundex - 3' as matching_algorithm, 0 as confirmedMatch
from #Match_AddrAndFEIN2

INSERT into Match_2016
SELECT *, null as distance, 'Soundex - 4' as matching_algorithm, 0 as confirmedMatch
from #Match_2016_exactAddrAndName2

INSERT into Match_2016
SELECT *, null as distance, 'Soundex - 5' as matching_algorithm, 0 as confirmedMatch
from #Match_2016_addrAndExactName2

INSERT into Match_2016
SELECT *, null as distance, 'Soundex - 6' as matching_algorithm, 0 as confirmedMatch
from #Match_2016_AddrAndName2

SELECT *, null as distance, 'FEIN Only' as matching_algorithm, 0 as confirmedMatch into Match_2016_FEINOnly
from #Match_2016_FEINOnly2

SELECT * INTO Match_2016_Unmatched
FROM #Working_WC

--Auto confirm "High Confidence" matches
UPDATE mat
SET confirmedMatch = 1
FROM Match_2016 mat
WHERE matching_algorithm IN ('Old Match', 'Levenshtein5 - 1', 'Levenshtein5 - 2', 'Levenshtein5 - 3', 'Soundex - 1', 'Soundex - 2', 'Soundex - 3', 'Soundex - 4', 'Soundex - 5')
AND wc_seq IN (
	SELECT wc_seq as county from match_2016 group by wc_seq having count(*) = 1
);

drop table #Working_WC;
drop table #Match_AddrAndFEIN2;
drop table #Match_All62;
drop table #Match_NameAndFEIN2;
drop table #Match_2016_exactAddrAndName2;
drop table #Match_2016_addrAndExactName2;
drop table #Match_2016_FEINOnly2;
drop table #Match_2016_AddrAndName2;

COMMIT