-- Infrequently updated tables. These tables act as a join target to create 0 data where no data currently exists.
-- These tables will need to be updated if new options are added to a filter, or new filters are added, or filter combinations are made invalid.

IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE Table_Name='Other_Filter_Nora_Sectors')
BEGIN
	DROP TABLE Other_Filter_Nora_Sectors;
END

IF EXISTS (SELECT 1 FROM INFORMATION_SCHEMA.TABLES WHERE Table_Name='Other_Filter_Naics')
BEGIN
	DROP TABLE Other_Filter_Naics;
END

--NORA Sector based other filters:
--Geographic Area includes 000, Odd numbers between 001-165, and 999.
--Injury type goes from 01 to 14
--Gender goes from 1 to 4
--NORA sectors go from 01 to 12
--Age Group goes from 1 to 4
--Company size goes from 01 to 05

DECLARE @GeographicArea varchar(max)
DECLARE @InjuryType varchar(max)
DECLARE @Gender varchar(max)
DECLARE @NoraSector varchar(max)
DECLARE @AgeGroup varchar(max)
DECLARE @CompanySize varchar(max)

SET @GeographicArea = '000,001,003,005,007,009,011,013,015,017,019,021,023,025,027,029,031,033,035,037,039,041,043,045,047,049,051,053,055,057,059,061,063,065,067,069,071,073,075,077,079,081,083,085,087,089,091,093,095,097,099,101,103,105,107,109,111,113,115,117,119,121,123,125,127,129,131,133,135,137,139,141,143,145,147,149,151,153,155,157,159,161,163,165,999'
SET @InjuryType = '01,02,03,04,05,06,07,08,09,10,11,12,13,14'
SET @Gender = '1,2,3,4'
SET @NoraSector = '01,02,03,04,05,06,07,08,09,10,11,12'
SET @AgeGroup = '1,2,3,4'
SET @CompanySize = '01,02,03,04,05'

--Cartesian Join to get every possible combination of other filters
SELECT * INTO Other_Filter_Nora_Sectors
FROM (SELECT value as GeographicArea FROM STRING_SPLIT(@GeographicArea, ',')) geographicArea,
	 (SELECT value as InjuryType FROM STRING_SPLIT(@InjuryType, ',')) injuryType,
	 (SELECT value as Gender FROM STRING_SPLIT(@Gender, ',')) gender,
	 (SELECT value as NoraSector FROM STRING_SPLIT(@NoraSector, ',')) noraSector,
	 (SELECT value as AgeGroup FROM STRING_SPLIT(@AgeGroup, ',')) ageGroup,
	 (SELECT value as CompanySize FROM STRING_SPLIT(@CompanySize, ',')) companySize

--Delete combinations of other filters that don't match up 
--Company size can only be matched with Injury Type
DELETE FROM Other_Filter_Nora_Sectors
WHERE CompanySize <> '01'
AND ( Gender <> '1' OR NoraSector <> '01' OR AgeGroup <> '1' OR GeographicArea <> '000');

--Body part specific sprain injuries cannot be matched with any other filter
DELETE FROM Other_Filter_Nora_Sectors
WHERE InjuryType IN ('07', '08', '09', '10')
AND ( Gender <> '1' OR NoraSector <> '01' OR AgeGroup <> '1' OR GeographicArea <> '000' OR CompanySize <> '01');

----Counties cannot be combined with age group or gender at all. Reverted, since we have county level data now
--DELETE FROM Other_Filter_Nora_Sectors
--WHERE GeographicArea <> '000'
--AND (AgeGroup <> '1' OR Gender <> '1')

----Public Safety cannot be combined with age group or gender. Reverted, the matching script will automatically ignore these when we don't know the correct ratio
--DELETE FROM Other_Filter_Nora_Sectors
--WHERE NoraSector = '09'
--AND (AgeGroup <> '1' OR Gender <> '1')

--NAICS code based other filters
--Company Size goes from 01 to 05 (same as above)
--Injury Type goes from 01 to 12 (same as above)
--Industry Type is a list of specific supported 3 digit NAICS codes

DECLARE @Naics varchar(max)
SET @Naics = '000,111,112,113,114,115,211,212,213,221,236,237,238,311,312,313,314,315,316,321,322,323,324,325,326,327,331,332,333,334,335,336,337,339,423,424,425,441,442,443,444,445,446,447,448,451,452,453,454,481,482,483,484,485,486,487,488,491,492,493,511,512,515,517,518,519,521,522,523,524,525,531,532,533,541,551,561,562,611,621,622,623,624,711,712,713,721,722,811,812,813,814,921,922,923,924,925,926,927,928'

--Cartesian Join to get every possible combination of other filters
SELECT * INTO Other_Filter_Naics
FROM (SELECT value as CompanySize FROM STRING_SPLIT(@CompanySize, ',')) companySize,
	 (SELECT value as InjuryType FROM STRING_SPLIT(@InjuryType, ',')) injuryType,
	 (SELECT value as Naics FROM STRING_SPLIT(@Naics, ',')) naicsCode;

--No combinations of other filters are invalid for this dataset