--Script outputs a MiTracking file. Set output to CSV, and remove the (X rows affected) statements from the results.

DECLARE @Year varchar(4)
SET @Year = '2014'

SELECT
CASE 
	WHEN EIN = 386000134 THEN '999'
	WHEN MEEI = 1 THEN 
		CASE
			WHEN CNTY <= 165 THEN RIGHT('000' + CNTY, 3)
			ELSE '999'
		END
	WHEN MEEI = 2 THEN '999'
	WHEN f.Zip IS NOT NULL THEN FORMAT(f.FIPS, '000')
	WHEN MEEI IS NULL THEN '999'
	WHEN CNTY <= 165 THEN RIGHT('000' + CNTY, 3)
	ELSE '999'
END AS GeographicArea, 
@Year AS Year,
CASE 
	WHEN [Injury Desc] IN('AMPUTATION') THEN '02'
	WHEN [Injury Desc] IN('CUT/LACERATION', 'ABRASION/SCRATCH', 'BITES-ANIMAL/HUMAN') THEN '03'
	WHEN [Injury Desc] IN('CRUSH/CONTUSION') THEN '04'
	WHEN [Injury Desc] IN('DISLOCATION', 'FRACTURE', 'HERNIA', 'INFLAMM JOINTS', 'INFLAM-JOINTS') THEN '05'
	WHEN [Injury Desc] IN('SPRAINS/STRAINS', 'NERVOUS SYSTEM', 'CNTRL NERV SYS', 'CARPAL TUNNEL', 'STRAINS/SPRAINS', 'NERVES') THEN '06'
	WHEN [Injury Desc] IN('BURN-HEAT', 'BURN-CHEMICAL', 'ELECTRIC SHOCK', 'BURN (HEAT)', 'BURN (CHEM)') THEN '11'
	WHEN [Injury Desc] IN('CONCUSSION') THEN '12'
	WHEN [Injury Desc] IN('SUFFOCATION', 'PARASITIC DISEASE', 'DYSENTERY', 'ANTHRAX', 'BRUCELLOSIS', 'CONJUNCTIVITIS', 'TETANUS', 'TUBERCULOSIS', 'INFECT DISEASE', 'DERMATITIS UNS', 'SKIN INFECTIONS', 'SKIN CONDITIONS', 'DERMATITIS ALLERG', 'SKIN COND NEC',
						  'FREEZING', 'HEARING LOSS', 'HEATSTROKE', 'POISONING', 'TOXIC MATERIAL', 'BLOOD DISEASE', 'UPPER RESPIR-TOXIC', 'RESPIRATORY, TOXIC', 'HEPATITIS, TOXIC', 'GASTROINTESTINAL', 'TOXIC POISONING', 'PNEUMOCONIOSIS', 'ALUMINOSIS',
						  'ANTHRACOSIS', 'ASBESTOSIS', 'BYSSINOSIS', 'SIDEROSIS', 'SILICOSIS', 'LUNG DISEASE', 'TB/PNEUMOCONIOSIS', 'RADIATION EFFECTS', 'SUNBURN', 'MICROWAVE', 'X-RAY', 'ISOTOPES', 'WELDERS'' FLASH', 'HEMORRHOIDS', 'HEPATITIS',
						  'EQUILIBRIUM', 'CEREBROVASCULAR', 'EYE DISEASES', 'STRESS', 'TUMOR/UNSPECIFIED', 'CANCER', 'BENIGN TUMOR', 'RESP SYS UNS', 'UPPER RESP', 'PNEUMONIA/FLU', 'RHINITIS', 'INSANITY/IMBECILITY', 'PARALYSIS', 'PROSTHETIC DAMAGE',
						  'OCCUP DISEASE', 'HEART ATTACK', 'DERMTITS ALLRG', 'WELDERS FLASH') THEN '13'
	ELSE '14'
END AS InjuryType,
CASE
	WHEN Gender IN ('M') THEN 2
	WHEN Gender IN ('F') THEN 3
	ELSE 4
END AS Gender,
CASE
	WHEN LEFT(naics, 2) IN ('11') THEN '02' --'Agriculture Forestry & Fishing (except Wildland Firefighting)'
	WHEN LEFT(naics, 2) IN ('23') THEN '03' --'Construction'
	WHEN LEFT(naics, 5) IN ('92212', '92214', '92216', '62191') THEN '04' --'Public Safety (including Wildland Firefighting)'
	WHEN LEFT(naics, 2) IN ('62') OR LEFT(naics, 5) IN ('54194', '81291') THEN '05' --'Healthcare & Social Assistance'
	WHEN LEFT(naics, 2) IN ('31', '32', '33') THEN '06' --'Manufacturing'
	WHEN LEFT(naics, 3) IN ('211') OR LEFT(naics, 6) IN ('213111', '213112') THEN '07' --'Oil & Gas Extraction'
	WHEN LEFT(naics, 2) IN ('21') THEN '08' --'Mining (except Oil & Gas Services)'
	WHEN LEFT(naics, 2) IN ('51', '52', '53', '54', '55', '56', '61', '71', '72', '81', '92') THEN '09' --'Services (except Public Safety)'
	WHEN LEFT(naics, 2) IN ('48', '49', '22') THEN '10' --'Transportation Warehousing & Utilities'
	WHEN LEFT(naics, 2) IN ('42', '44', '45') THEN '11' --'Wholesale & Retail Trade'
	ELSE '12'
END AS Naics,
CASE
	WHEN [date of injury] - DOB < 250000 THEN 2
	WHEN [date of injury] - DOB < 540000 THEN 3
	ELSE 4
END AS AgeGroup,
CASE
	WHEN employees > 0 AND employees <= 10 THEN '02'
	WHEN employees > 10 AND employees < 250 THEN '03'
	WHEN employees >= 250 THEN '04'
	ELSE '05'
END AS CompanySize,
[Part of Body Desc]
INTO #MatchBreakdown_FTE
FROM Match_2014_Confirmed m
LEFT JOIN (
	SELECT 
		(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 as employees,
		ui_acct
	FROM Emp_2014
	WHERE (MEEI IN (1, 3, 4, 5, 6) OR MEEI IS NULL)
	AND CNTY NOT IN (996, 998)
	GROUP BY ui_acct
	) as emp ON m.ui_acct = emp.ui_acct
LEFT JOIN fips f ON m.[Employer Zip] = f.Zip;

SELECT 
	CASE
		WHEN LEFT(naics, 2) IN ('11') THEN '02' --'Agriculture Forestry & Fishing (except Wildland Firefighting)'
		WHEN LEFT(naics, 2) IN ('23') THEN '03' --'Construction'
		WHEN LEFT(naics, 5) IN ('92212', '92214', '92216', '62191') THEN '04' --'Public Safety (including Wildland Firefighting)'
		WHEN LEFT(naics, 2) IN ('62') OR LEFT(naics, 5) IN ('54194', '81291') THEN '05' --'Healthcare & Social Assistance'
		WHEN LEFT(naics, 2) IN ('31', '32', '33') THEN '06' --'Manufacturing'
		WHEN LEFT(naics, 3) IN ('211') OR LEFT(naics, 6) IN ('213111', '213112') THEN '07' --'Oil & Gas Extraction'
		WHEN LEFT(naics, 2) IN ('21') THEN '08' --'Mining (except Oil & Gas Services)'
		WHEN LEFT(naics, 2) IN ('51', '52', '53', '54', '55', '56', '61', '71', '72', '81', '92') THEN '09' --'Services (except Public Safety)'
		WHEN LEFT(naics, 2) IN ('48', '49', '22') THEN '10' --'Transportation Warehousing & Utilities'
		WHEN LEFT(naics, 2) IN ('42', '44', '45') THEN '11' --'Wholesale & Retail Trade'
	END AS Naics, 
	CASE
		WHEN EIN = 386000134 THEN '999'
		WHEN CNTY <= 165 THEN CNTY
		ELSE '999'
	END AS GeographicArea,
	ui_acct,
	CASE
		WHEN 
			(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 > 0 
			AND (SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 <= 10 
			THEN '02'
		WHEN 
			(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 > 10 
			AND (SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 < 250 
			THEN '03'
		WHEN 
			(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 >= 250 
		THEN '04'
		ELSE '05'
	END AS CompanySize,
	(SUM(COALESCE(M1_EMPL, 0)) + SUM(COALESCE(M2_EMPL, 0)) + SUM(COALESCE(M3_EMPL, 0)) + SUM(COALESCE(M4_EMPL, 0)) + SUM(COALESCE(M5_EMPL, 0)) + SUM(COALESCE(M6_EMPL, 0)) + SUM(COALESCE(M7_EMPL, 0)) + SUM(COALESCE(M8_EMPL, 0)) + SUM(COALESCE(M9_EMPL, 0)) + SUM(COALESCE(M10_EMPL, 0)) + SUM(COALESCE(M11_EMPL, 0)) + SUM(COALESCE(M12_EMPL, 0))) / 12.0 as employees
INTO #CompanyBreakdown_FTE
FROM emp_2014
WHERE MEEI IN (1, 3, 4, 5, 6)
AND CNTY NOT IN (996, 998)
GROUP BY 
	CASE
		WHEN LEFT(naics, 2) IN ('11') THEN '02' --'Agriculture Forestry & Fishing (except Wildland Firefighting)'
		WHEN LEFT(naics, 2) IN ('23') THEN '03' --'Construction'
		WHEN LEFT(naics, 5) IN ('92212', '92214', '92216', '62191') THEN '04' --'Public Safety (including Wildland Firefighting)'
		WHEN LEFT(naics, 2) IN ('62') OR LEFT(naics, 5) IN ('54194', '81291') THEN '05' --'Healthcare & Social Assistance'
		WHEN LEFT(naics, 2) IN ('31', '32', '33') THEN '06' --'Manufacturing'
		WHEN LEFT(naics, 3) IN ('211') OR LEFT(naics, 6) IN ('213111', '213112') THEN '07' --'Oil & Gas Extraction'
		WHEN LEFT(naics, 2) IN ('21') THEN '08' --'Mining (except Oil & Gas Services)'
		WHEN LEFT(naics, 2) IN ('51', '52', '53', '54', '55', '56', '61', '71', '72', '81', '92') THEN '09' --'Services (except Public Safety)'
		WHEN LEFT(naics, 2) IN ('48', '49', '22') THEN '10' --'Transportation Warehousing & Utilities'
		WHEN LEFT(naics, 2) IN ('42', '44', '45') THEN '11' --'Wholesale & Retail Trade'
	END, 
	CASE
		WHEN EIN = 386000134 THEN '999'
		WHEN CNTY <= 165 THEN CNTY
		ELSE '999'
	END,
	ui_acct


SELECT mat.GeographicArea, mat.Year, mat.InjuryType, mat.Gender, mat.Naics, mat.AgeGroup, mat.CompanySize,
	CASE 
		WHEN SUM(Cases) < 6 AND SUM(Cases) > 0 THEN '' 
		WHEN com.numberOfCompanies < 6 THEN '' 
		WHEN SUM(Cases) IS NULL THEN ''
		WHEN Employees IS NULL THEN ''
		ELSE FORMAT((SUM(Cases) / (Employees * 
		CASE
			WHEN mat.naics = '01' THEN 0.961
			WHEN mat.naics = '02' THEN 1.043
			WHEN mat.naics = '03' THEN 1.051
			WHEN mat.naics = '04' THEN 0.992
			WHEN mat.naics = '05' THEN 0.911
			WHEN mat.naics = '06' THEN 1.095
			WHEN mat.naics = '07' THEN 1.227
			WHEN mat.naics = '08' THEN 1.199
			WHEN mat.naics = '09' THEN 0.903
			WHEN mat.naics = '10' THEN 1.102
			WHEN mat.naics = '11' THEN 0.900
			ELSE 1.000
		END
		* Modifier
		) * 100 ), '0.000')
	END AS Rate
FROM (
	--all filters
	SELECT GeographicArea, Year, InjuryType, Gender, Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, InjuryType, Gender, Naics, AgeGroup

	UNION

	--ignore injury type
	SELECT GeographicArea, Year, '01' as InjuryType, Gender, Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, Gender, Naics, AgeGroup

	UNION

	--ignore gender
	SELECT GeographicArea, Year, InjuryType, 1 as Gender, Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, InjuryType, Naics, AgeGroup

	UNION

	--ignore injury type, gender
	SELECT GeographicArea, Year, '01' as InjuryType, 1 as Gender, Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, Naics, AgeGroup

	UNION

	--ignore naics
	SELECT GeographicArea, Year, InjuryType, Gender, '01' as Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, InjuryType, Gender, AgeGroup

	UNION

	--ignore injury type, naics
	SELECT GeographicArea, Year, '01' as InjuryType, Gender, '01' as Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, Gender, AgeGroup

	UNION

	--ignore gender, naics
	SELECT GeographicArea, Year, InjuryType, 1 as Gender, '01' as Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, InjuryType, AgeGroup

	UNION

	--ignore injury type, gender, naics
	SELECT GeographicArea, Year, '01' as InjuryType, 1 as Gender, '01' as Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, AgeGroup

	UNION
	
	--ignore age group
	SELECT GeographicArea, Year, InjuryType, Gender, Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, InjuryType, Gender, Naics

	UNION

	--ignore injury type, age group
	SELECT GeographicArea, Year, '01' as InjuryType, Gender, Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, Gender, Naics

	UNION

	--ignore gender, age group
	SELECT GeographicArea, Year, InjuryType, 1 as Gender, Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, InjuryType, Naics

	UNION

	--ignore injury type, gender, age group
	SELECT GeographicArea, Year, '01' as InjuryType, 1 as Gender, Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, Naics

	UNION

	--ignore naics, age group
	SELECT GeographicArea, Year, InjuryType, Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, InjuryType, Gender

	UNION

	--ignore injury type, naics, age group
	SELECT GeographicArea, Year, '01' as InjuryType, Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, Gender

	UNION

	--ignore gender, naics, age group
	SELECT GeographicArea, Year, InjuryType, 1 as Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year, InjuryType

	UNION

	--ignore injury type, gender, naics, age group
	SELECT GeographicArea, Year, '01' as InjuryType, 1 as Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY GeographicArea, Year

	UNION
	
	--ignore geographic area
	SELECT '000' as GeographicArea, Year, InjuryType, Gender, Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, InjuryType, Gender, Naics, AgeGroup

	UNION

	--ignore geographic area, injury type
	SELECT '000' as GeographicArea, Year, '01' as InjuryType, Gender, Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, Gender, Naics, AgeGroup

	UNION

	--ignore geographic area, gender
	SELECT '000' as GeographicArea, Year, InjuryType, 1 as Gender, Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, InjuryType, Naics, AgeGroup

	UNION

	--ignore geographic area, injury type, gender
	SELECT '000' as GeographicArea, Year, '01' as InjuryType, 1 as Gender, Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, Naics, AgeGroup

	UNION

	--ignore geographic area, naics
	SELECT '000' as GeographicArea, Year, InjuryType, Gender, '01' as Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, InjuryType, Gender, AgeGroup

	UNION

	--ignore geographic area, injury type, naics
	SELECT '000' as GeographicArea, Year, '01' as InjuryType, Gender, '01' as Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, Gender, AgeGroup

	UNION

	--ignore geographic area, gender, naics
	SELECT '000' as GeographicArea, Year, InjuryType, 1 as Gender, '01' as Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, InjuryType, AgeGroup

	UNION

	--ignore geographic area, injury type, gender, naics
	SELECT '000' as GeographicArea, Year, '01' as InjuryType, 1 as Gender, '01' as Naics, AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, AgeGroup

	UNION
	
	--ignore geographic area, age group
	SELECT '000' as GeographicArea, Year, InjuryType, Gender, Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, InjuryType, Gender, Naics

	UNION

	--ignore geographic area, injury type, age group
	SELECT '000' as GeographicArea, Year, '01' as InjuryType, Gender, Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, Gender, Naics

	UNION

	--ignore geographic area, gender, age group
	SELECT '000' as GeographicArea, Year, InjuryType, 1 as Gender, Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, InjuryType, Naics

	UNION

	--ignore geographic area, injury type, gender, age group
	SELECT '000' as GeographicArea, Year, '01' as InjuryType, 1 as Gender, Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, Naics

	UNION

	--ignore geographic area, naics, age group
	SELECT '000' as GeographicArea, Year, InjuryType, Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, InjuryType, Gender

	UNION

	--ignore geographic area, injury type, naics, age group
	SELECT '000' as GeographicArea, Year, '01' as InjuryType, Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, Gender

	UNION

	--ignore geographic area, gender, naics, age group
	SELECT '000' as GeographicArea, Year, InjuryType, 1 as Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year, InjuryType

	UNION

	--ignore geographic area, injury type, gender, naics, age group
	SELECT '000' as GeographicArea, Year, '01' as InjuryType, 1 as Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, '01' as CompanySize
	FROM #MatchBreakdown_FTE
	GROUP BY Year

	UNION

	--Special handling for sprain injury locations.
	SELECT 
		'000' as GeographicArea, 
		Year, 
		CASE
			WHEN [Part of Body Desc] IN('BACK') THEN '07'
			WHEN [Part of Body Desc] IN('SHOULDER(S)') THEN '08'
			WHEN [Part of Body Desc] IN('KNEE') THEN '09'
			WHEN [Part of Body Desc] IN('FINGER', 'FOREARM', 'HAND/FINGER(S)', 'ELBOW', 'ARM(S), UNS', 'UPPER ARM', 'HAND(S)', 'WRIST', 'ARM, NEC', 'UPP EXT UNS', 'UPP EXT MULTIPLE', 'ARM MULTIPLE') THEN '10'
		END as InjuryType, 
		1 as Gender, 
		'01' as Naics, 
		1 as AgeGroup, 
		count(*) as Cases, 
		'01' as CompanySize
	FROM #MatchBreakdown_FTE
	WHERE InjuryType = '06'
	AND [Part of Body Desc] IN('BACK', 'SHOULDER(S)', 'KNEE', 'FINGER', 'FOREARM', 'HAND/FINGER(S)', 'ELBOW', 'ARM(S), UNS', 'UPPER ARM', 'HAND(S)', 'WRIST', 'ARM, NEC', 'UPP EXT UNS', 'UPP EXT MULTIPLE', 'ARM MULTIPLE')
	GROUP BY 
		Year,
		CASE
			WHEN [Part of Body Desc] IN('BACK') THEN '07'
			WHEN [Part of Body Desc] IN('SHOULDER(S)') THEN '08'
			WHEN [Part of Body Desc] IN('KNEE') THEN '09'
			WHEN [Part of Body Desc] IN('FINGER', 'FOREARM', 'HAND/FINGER(S)', 'ELBOW', 'ARM(S), UNS', 'UPPER ARM', 'HAND(S)', 'WRIST', 'ARM, NEC', 'UPP EXT UNS', 'UPP EXT MULTIPLE', 'ARM MULTIPLE') THEN '10'
		END

	UNION

	--Special handling for company size with industry
	SELECT GeographicArea, Year, InjuryType, Gender, Naics, AgeGroup, Cases, CompanySize
	FROM (
		SELECT '000' as GeographicArea, Year, InjuryType, 1 as Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, CompanySize
		FROM #MatchBreakdown_FTE
		GROUP BY InjuryType, CompanySize, Year

		UNION

		SELECT '000' as GeographicArea, Year, '01' as InjuryType, 1 as Gender, '01' as Naics, 1 as AgeGroup, count(*) as Cases, CompanySize
		FROM #MatchBreakdown_FTE
		GROUP BY CompanySize, Year
	) companySize

	UNION

	--Add in zero rows for all possible combinations of filters
	SELECT GeographicArea, @Year as Year, InjuryType, Gender, NoraSector as Naics, AgeGroup, 0 as Cases, CompanySize
	FROM Other_Filter_Nora_Sectors
) AS mat
LEFT JOIN 
(
	SELECT Naics, GeographicArea, CompanySize, SUM(employees) as employees
	FROM #CompanyBreakdown_FTE
	GROUP BY Naics, GeographicArea, CompanySize

	UNION

	SELECT Naics, '000' as GeographicArea, CompanySize, SUM(employees) as employees
	FROM #CompanyBreakdown_FTE
	GROUP BY Naics, CompanySize

	UNION
	
	SELECT '01' as Naics, GeographicArea, CompanySize, SUM(employees) as employees
	FROM #CompanyBreakdown_FTE
	GROUP BY GeographicArea, CompanySize

	UNION

	SELECT '01' as Naics, '000' as GeographicArea, CompanySize, SUM(employees) as employees
	FROM #CompanyBreakdown_FTE
	GROUP BY CompanySize

	UNION
	
	SELECT Naics, GeographicArea, '01' as CompanySize, SUM(employees) as employees
	FROM #CompanyBreakdown_FTE
	GROUP BY Naics, GeographicArea

	UNION

	SELECT Naics, '000' as GeographicArea, '01' as CompanySize, SUM(employees) as employees
	FROM #CompanyBreakdown_FTE
	GROUP BY Naics

	UNION
	
	SELECT '01' as Naics, GeographicArea, '01' as CompanySize, SUM(employees) as employees
	FROM #CompanyBreakdown_FTE
	GROUP BY GeographicArea

	UNION

	SELECT '01' as Naics, '000' as GeographicArea, '01' as CompanySize, SUM(employees) as employees
	FROM #CompanyBreakdown_FTE
) AS denom ON mat.naics = denom.naics AND mat.GeographicArea = denom.GeographicArea AND mat.CompanySize = denom.CompanySize
LEFT JOIN (
	SELECT 
		CASE
			WHEN LEFT(naics, 2) IN ('11') THEN '02'                                                             --'Agriculture Forestry & Fishing (except Wildland Firefighting)'
			WHEN LEFT(naics, 2) IN ('23') THEN '03'                                                             --'Construction'
			WHEN LEFT(naics, 5) IN ('92212', '92214', '92216', '62191') THEN '04'                               --'Public Safety (including Wildland Firefighting)'
			WHEN LEFT(naics, 2) IN ('62') OR LEFT(naics, 5) IN ('54194', '81291') THEN '05'                     --'Healthcare & Social Assistance'
			WHEN LEFT(naics, 2) IN ('31', '32', '33') THEN '06'                                                 --'Manufacturing'
			WHEN LEFT(naics, 3) IN ('211') OR LEFT(naics, 6) IN ('213111', '213112') THEN '07'                  --'Oil & Gas Extraction'
			WHEN LEFT(naics, 2) IN ('21') THEN '08'                                                             --'Mining (except Oil & Gas Services)'
			WHEN LEFT(naics, 2) IN ('51', '52', '53', '54', '55', '56', '61', '71', '72', '81', '92') THEN '09' --'Services (except Public Safety)'
			WHEN LEFT(naics, 2) IN ('48', '49', '22') THEN '10'                                                 --'Transportation Warehousing & Utilities'
			WHEN LEFT(naics, 2) IN ('42', '44', '45') THEN '11'                                                 --'Wholesale & Retail Trade'
			ELSE '12'
		END AS Naics, 
		CASE
			WHEN cnty <= 165 THEN cnty
			ELSE '999'
		END as cnty, 
		count(*) as numberOfCompanies
	FROM emp_2014
	WHERE MEEI IN (1, 3, 4, 5, 6)
	AND CNTY NOT IN (996, 998)
	GROUP BY 
	CASE
		WHEN LEFT(naics, 2) IN ('11') THEN '02'                                                             --'Agriculture Forestry & Fishing (except Wildland Firefighting)'
		WHEN LEFT(naics, 2) IN ('23') THEN '03'                                                             --'Construction'
		WHEN LEFT(naics, 5) IN ('92212', '92214', '92216', '62191') THEN '04'                               --'Public Safety (including Wildland Firefighting)'
		WHEN LEFT(naics, 2) IN ('62') OR LEFT(naics, 5) IN ('54194', '81291') THEN '05'                     --'Healthcare & Social Assistance'
		WHEN LEFT(naics, 2) IN ('31', '32', '33') THEN '06'                                                 --'Manufacturing'
		WHEN LEFT(naics, 3) IN ('211') OR LEFT(naics, 6) IN ('213111', '213112') THEN '07'                  --'Oil & Gas Extraction'
		WHEN LEFT(naics, 2) IN ('21') THEN '08'                                                             --'Mining (except Oil & Gas Services)'
		WHEN LEFT(naics, 2) IN ('51', '52', '53', '54', '55', '56', '61', '71', '72', '81', '92') THEN '09' --'Services (except Public Safety)'
		WHEN LEFT(naics, 2) IN ('48', '49', '22') THEN '10'                                                 --'Transportation Warehousing & Utilities'
		WHEN LEFT(naics, 2) IN ('42', '44', '45') THEN '11'                                                 --'Wholesale & Retail Trade'
		ELSE '12'
	END, 
	CASE
		WHEN cnty <= 165 THEN cnty
		ELSE '999'
	END

	UNION

	SELECT
		'01' AS Naics,
		CASE
			WHEN cnty <= 165 THEN cnty
			ELSE '999'
		END as cnty, 
		count(*) as numberOfCompanies
	FROM emp_2014
	WHERE MEEI IN (1, 3, 4, 5, 6)
	AND CNTY NOT IN (996, 998)
	GROUP BY  
	CASE
		WHEN cnty <= 165 THEN cnty
		ELSE '999'
	END

	UNION

	SELECT
		CASE
			WHEN LEFT(naics, 2) IN ('11') THEN '02'                                                             --'Agriculture Forestry & Fishing (except Wildland Firefighting)'
			WHEN LEFT(naics, 2) IN ('23') THEN '03'                                                             --'Construction'
			WHEN LEFT(naics, 5) IN ('92212', '92214', '92216', '62191') THEN '04'                               --'Public Safety (including Wildland Firefighting)'
			WHEN LEFT(naics, 2) IN ('62') OR LEFT(naics, 5) IN ('54194', '81291') THEN '05'                     --'Healthcare & Social Assistance'
			WHEN LEFT(naics, 2) IN ('31', '32', '33') THEN '06'                                                 --'Manufacturing'
			WHEN LEFT(naics, 3) IN ('211') OR LEFT(naics, 6) IN ('213111', '213112') THEN '07'                  --'Oil & Gas Extraction'
			WHEN LEFT(naics, 2) IN ('21') THEN '08'                                                             --'Mining (except Oil & Gas Services)'
			WHEN LEFT(naics, 2) IN ('51', '52', '53', '54', '55', '56', '61', '71', '72', '81', '92') THEN '09' --'Services (except Public Safety)'
			WHEN LEFT(naics, 2) IN ('48', '49', '22') THEN '10'                                                 --'Transportation Warehousing & Utilities'
			WHEN LEFT(naics, 2) IN ('42', '44', '45') THEN '11'                                                 --'Wholesale & Retail Trade'
			ELSE '12'
		END AS Naics,
		'000' as cnty,
		count(*) as numberOfCompanies
	FROM emp_2014
	WHERE MEEI IN (1, 3, 4, 5, 6)
	AND CNTY NOT IN (996, 998)
	GROUP BY 
		CASE
			WHEN LEFT(naics, 2) IN ('11') THEN '02'                                                             --'Agriculture Forestry & Fishing (except Wildland Firefighting)'
			WHEN LEFT(naics, 2) IN ('23') THEN '03'                                                             --'Construction'
			WHEN LEFT(naics, 5) IN ('92212', '92214', '92216', '62191') THEN '04'                               --'Public Safety (including Wildland Firefighting)'
			WHEN LEFT(naics, 2) IN ('62') OR LEFT(naics, 5) IN ('54194', '81291') THEN '05'                     --'Healthcare & Social Assistance'
			WHEN LEFT(naics, 2) IN ('31', '32', '33') THEN '06'                                                 --'Manufacturing'
			WHEN LEFT(naics, 3) IN ('211') OR LEFT(naics, 6) IN ('213111', '213112') THEN '07'                  --'Oil & Gas Extraction'
			WHEN LEFT(naics, 2) IN ('21') THEN '08'                                                             --'Mining (except Oil & Gas Services)'
			WHEN LEFT(naics, 2) IN ('51', '52', '53', '54', '55', '56', '61', '71', '72', '81', '92') THEN '09' --'Services (except Public Safety)'
			WHEN LEFT(naics, 2) IN ('48', '49', '22') THEN '10'                                                 --'Transportation Warehousing & Utilities'
			WHEN LEFT(naics, 2) IN ('42', '44', '45') THEN '11'                                                 --'Wholesale & Retail Trade'
			ELSE '12'
		END

	UNION

	SELECT
		'01' as Naics,
		'000' as cnty,
		count(*) as numberOfCompanies
	FROM emp_2014
	WHERE MEEI IN (1, 3, 4, 5, 6)
	AND CNTY NOT IN (996, 998)

) AS com ON mat.Naics = com.Naics AND mat.GeographicArea = com.cnty
LEFT JOIN MiTracking_Modifiers mm on mat.Naics = mm.NoraSector AND mat.AgeGroup = mm.Age AND mat.Gender = mm.Gender AND mat.GeographicArea = mm.GeographicArea AND mm.Year = @Year
WHERE NOT (mat.naics = '12' OR mat.Gender = 4 OR mat.GeographicArea = '999' OR mat.CompanySize = '05') --Ignore unknowns
AND denom.employees != 0 -- Throw out counties that have no employees, so they show up as an unknown rate
AND NOT (mat.Naics = '04' AND (mat.AgeGroup <> 1 OR mat.Gender <> 1)) -- Do not allow gender or age group filters for public safety, since we don't have good values on those
AND mm.Modifier IS NOT NULL -- Throw out datapoints that have an unknown modifier
GROUP BY mat.Year, mat.GeographicArea, InjuryType, mat.Gender, AgeGroup, mat.Naics, mat.CompanySize, com.numberOfCompanies, denom.employees, Modifier
ORDER BY mat.Year, GeographicArea, InjuryType, Gender, Naics, AgeGroup, CompanySize;

DROP TABLE #MatchBreakdown_FTE;
DROP TABLE #CompanyBreakdown_FTE;